@@ -1,6 +1,6 @@
 package DNS::Oterica::Hub;
 # ABSTRACT: the center of control for a DNS::Oterica system
-$DNS::Oterica::Hub::VERSION = '0.313';
+$DNS::Oterica::Hub::VERSION = '0.314';
 use Moose;
 with 'DNS::Oterica::Role::RecordMaker';
 
@@ -284,7 +284,7 @@ DNS::Oterica::Hub - the center of control for a DNS::Oterica system
 
 =head1 VERSION
 
-version 0.313
+version 0.314
 
 =head1 OVERVIEW
 
@@ -376,11 +376,11 @@ initialization.)
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@semiotic.systems>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
