@@ -1,6 +1,6 @@
 package DNS::Oterica::Network;
 # ABSTRACT: a network to which results are served
-$DNS::Oterica::Network::VERSION = '0.313';
+$DNS::Oterica::Network::VERSION = '0.314';
 use Moose;
 
 use Net::IP;
@@ -107,7 +107,7 @@ DNS::Oterica::Network - a network to which results are served
 
 =head1 VERSION
 
-version 0.313
+version 0.314
 
 =head1 OVERVIEW
 
@@ -138,11 +138,11 @@ This is the C<Net::IP> ranges for the network at this network.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@semiotic.systems>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
