@@ -1,6 +1,6 @@
 package DNS::Oterica::Node;
 # ABSTRACT: DNSO node. belongs to families. 
-$DNS::Oterica::Node::VERSION = '0.313';
+$DNS::Oterica::Node::VERSION = '0.314';
 use Moose;
 
 use DNS::Oterica::Role::RecordMaker;
@@ -99,7 +99,7 @@ DNS::Oterica::Node - DNSO node. belongs to families.
 
 =head1 VERSION
 
-version 0.313
+version 0.314
 
 =head1 OVERVIEW
 
@@ -155,11 +155,11 @@ By default, it returns nothing.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@semiotic.systems>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
