@@ -1,6 +1,6 @@
 package DNS::Oterica::Node::Host;
 # ABSTRACT: a host node
-$DNS::Oterica::Node::Host::VERSION = '0.313';
+$DNS::Oterica::Node::Host::VERSION = '0.314';
 use Moose;
 extends 'DNS::Oterica::Node';
 
@@ -133,7 +133,7 @@ DNS::Oterica::Node::Host - a host node
 
 =head1 VERSION
 
-version 0.313
+version 0.314
 
 =head1 OVERVIEW
 
@@ -186,11 +186,11 @@ This is the fully-qualified domain name of this host.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@semiotic.systems>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
