@@ -1,6 +1,6 @@
 package DNS::Oterica::NodeFamily;
 # ABSTRACT: a group of hosts that share common functions
-$DNS::Oterica::NodeFamily::VERSION = '0.313';
+$DNS::Oterica::NodeFamily::VERSION = '0.314';
 use Moose;
 
 #pod =attr nodes
@@ -73,7 +73,7 @@ DNS::Oterica::NodeFamily - a group of hosts that share common functions
 
 =head1 VERSION
 
-version 0.313
+version 0.314
 
 =head1 PERL VERSION
 
@@ -107,11 +107,11 @@ by subclasses.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@semiotic.systems>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
