@@ -1,6 +1,6 @@
 package DNS::Oterica::Role::HasHub;
 # ABSTRACT: any part of the dnso system that has a reference to the hub
-$DNS::Oterica::Role::HasHub::VERSION = '0.313';
+$DNS::Oterica::Role::HasHub::VERSION = '0.314';
 use Moose::Role;
 
 use namespace::autoclean;
@@ -28,7 +28,7 @@ DNS::Oterica::Role::HasHub - any part of the dnso system that has a reference to
 
 =head1 VERSION
 
-version 0.313
+version 0.314
 
 =head1 PERL VERSION
 
@@ -42,11 +42,11 @@ the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@semiotic.systems>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo SIGNES.
+This software is copyright (c) 2022 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
